@@ -108,15 +108,15 @@ class KGET_EXPORT FileModel : public QAbstractItemModel
         FileModel(const QList<QUrl> &files, const QUrl &destDirectory, QObject *parent = nullptr);
         ~FileModel();
 
-        QVariant data(const QModelIndex &index, int role) const;
-        bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
-        Qt::ItemFlags flags(const QModelIndex &index) const;
-        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-        QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
+        QVariant data(const QModelIndex &index, int role) const override;
+        bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+        Qt::ItemFlags flags(const QModelIndex &index) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+        QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
         QModelIndex index(const QUrl &file, int column);
-        QModelIndex parent(const QModelIndex &index) const;
-        int rowCount(const QModelIndex &parent = QModelIndex()) const;
-        int columnCount(const QModelIndex &parent = QModelIndex()) const;
+        QModelIndex parent(const QModelIndex &index) const override;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+        int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
         void rename(const QModelIndex &file, const QString &newName);
 
